summary.bayesmixsurv: Summarizing BayesMixSurv model fits
Description
summary method for class "bayesmixsurv".
Usage
# S3 method for bayesmixsurv
summary(object, pval = 0.05, burnin = object$control$burnin, ...)
# S3 method for summary.bayesmixsurv
print(x, ...)
Value
An object of class summary.bayesmixsurv, with the following elements:
call
The matched call.
pval
Same as input.
burnin
Same as input.
single
Copied from object$control$single. See bayesmixsurv.control for explanation.
coefficients
A list including matrices alpha, beta1, beta2, and gamma (if stratification is used). Each matrix has columns named 'Estimate', 'Lower Bound', 'Upper Bound', and 'P-val'. alpha has two rows, one for each components, while each of beta1 and beta2 has one row per covariate. gamma has one row per stratum (except for the reference stratum).
Arguments
object
An object of class 'bayesmixsurv', usually the result of a call to bayesmixsurv.
x
An object of class "summary.bayesmixsurv", usually the result of a call to summary.bayesmixsurv.
pval
Desired p-value, based on which lower/upper bounds will be calculated. Default is 0.05.
burnin
Number of samples to discard from the beginning of each MCMC chain before calculating median and lower/upper bounds.
...
Further arguments to be passed to/from other methods.
Author
Alireza S. Mahani, Mansour T.A. Sharabiani
See Also
See summary for a description of the generic method.